==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$UnmodifiablePrintRequestAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 331ae21ae563dec4 javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet
// @dep_class a510e2f0795dfb9a javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24UnmodifiableAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintRequestAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$method$_init$0ca123b9de7369cc(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$UnmodifiablePrintRequestAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 331ae21ae563dec4 javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet
// @dep_class a510e2f0795dfb9a javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24UnmodifiableAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintRequestAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$method$_init$0ca123b9de7369cc(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiableAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24UnmodifiablePrintRequestAttributeSet_H_ */
